Learn R Programming

SPIGA (version 1.0.0)

SPIDataset: The data set for illustratrating the functions of the SPIGA package

Description

The set used, data are monthly rainfall (1981-2015) and the dimensionless parameters to calculate the SPI drought.

Usage

data(Pm_Pisco) data(alphaGA_SPI3) data(betaGA_SPI3)

Arguments

Format

Pm_Pisco dataframe with:
YEAR
monthly precipitation totals, in mm.
MONTH
monthly precipitation totals, in mm.
P1
monthly precipitation totals st-1, in mm.
P2
monthly precipitation totals st-2, in mm.
...
monthly precipitation totals st-n, in mm.
alphaGA_SPI3 dataset: monthly alpha parameter.
mon
month analysis
st-1
monthly alpha parameter station 1
st-2
monthly alpha parameter station 2
st-n
monthly alpha parameter station n
betaGA_SPI3 dataset: monthly beta parameter.
mon
month analysis
st-1
monthly beta parameter station 1
st-2
monthly beta parameter station 2
st-n
monthly beta parameter station n

The Pm_Pisco data were obtained from the Peruvian Interpolation data of the SENAMHI's Climatological and Hidrological Observations, SENAMHI-PERU. http://peruclima.pe/.

References

McKee, Thomas B. and Doesken, Nolan J. and Kleist, John. 1993. The relationship of Drought Frequency and Duration to Time Scales. Eighth Conference on Applied Climatology

A. Belauneh and J. Adamowski. Standard Precipitation Index Drought Forecasting Using Neural Networks, Wavelet Neural Networks, and Support Vector Regression. Applied Computational Intelligence and Soft Computing, http://dx.doi.org/10.1155/2012/794061

Examples

Run this code
data(Pm_Pisco)
names(Pm_Pisco)
summary(Pm_Pisco)

data(alphaGA_SPI3)
names(alphaGA_SPI3)
summary(alphaGA_SPI3)

data(betaGA_SPI3)
names(betaGA_SPI3)
summary(betaGA_SPI3)

Run the code above in your browser using DataLab